==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/et-EE/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'kasutaja saab sisse logida',
    'activated_disabled_help_text' => 'Te ei saa iseenda konto aktiveerimis staatust muuta.',
    'assets_user'       => 'Kasutajaga :name seotud vahendid',
    'bulk_update_warn'	=> 'Sa oled muutmas :user_count kasutaja andmeid. Palun pane tähele, et saa ei saa selle vormi kaudu muuta enda kasutaja andmeid, neid pead muutma eraldi.',
    'bulk_update_help'	=> 'Selle vormiga saad muuta mitmeid kasutajaid korraga. Täida ainult need väljad, mida on vaja muuta. Tühjaks jäetud väljasid ei muudeta.',
    'current_assets'    => 'Selle kasutaja valduses olevad vahendid',
    'clone'             => 'Klooni kasutaja',
    'contact_user'      => 'Võta ühendust :name-ga',
    'edit'              => 'Muuda kasutajat',
    'filetype_info'     => 'Lubatud failitüübid on png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, ja rar.',
    'history_user'      => 'Kasutaja :name ajalugu',
    'info'				=> 'Info',
    'restore_user'		=> 'Nende taastamiseks klõpsake siin.',
    'last_login'        => 'Viimane sisselogimine',
    'ldap_config_text'  => 'LDAP-i konfiguratsiooniseadeid saab leida Admin> Seaded. (Valikuline) valitud asukoht määratakse kõigi imporditud kasutajate jaoks.',
    'print_assigned'    => 'Prindi kõik varad',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Kasutaja :name valdusesse antud tarkvara',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Vaata kasutajat :name',
    'usercsv'           => 'CSV fail',
    'two_factor_admin_optin_help' => 'Sinu praegused admin seaded lubavad kahe-astmelist autantimis jõustada valikulselt. ',
    'two_factor_enrolled' => '2FA-seade on registreeritud',
    'two_factor_active'   => '2FA aktiivne ',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Uuenda kõik vahendid nendele kasutajatele sellesse olekusse',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'See on kaugkasutaja',
    'remote'   => 'Remote',
    'remote_help' => 'See võib olla kasulik, kui vajad kaugkasutajate filtrit inimestest, kes käivad harva või ei käi üldse ettevõtte füüsilistes asukohtades.',
    'not_remote_label' => 'See ei ole kaugkasutaja',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/et-EE/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'kasutaja saab sisse logida',
    'activated_disabled_help_text' => 'Te ei saa iseenda konto aktiveerimis staatust muuta.',
    'assets_user'       => 'Kasutajaga :name seotud vahendid',
    'bulk_update_warn'	=> 'Sa oled muutmas :user_count kasutaja andmeid. Palun pane tähele, et saa ei saa selle vormi kaudu muuta enda kasutaja andmeid, neid pead muutma eraldi.',
    'bulk_update_help'	=> 'Selle vormiga saad muuta mitmeid kasutajaid korraga. Täida ainult need väljad, mida on vaja muuta. Tühjaks jäetud väljasid ei muudeta.',
    'current_assets'    => 'Selle kasutaja valduses olevad vahendid',
    'clone'             => 'Klooni kasutaja',
    'contact_user'      => 'Võta ühendust :name-ga',
    'edit'              => 'Muuda kasutajat',
    'filetype_info'     => 'Lubatud failitüübid on png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, ja rar.',
    'history_user'      => 'Kasutaja :name ajalugu',
    'info'				=> 'Info',
    'restore_user'		=> 'Nende taastamiseks klõpsake siin.',
    'last_login'        => 'Viimane sisselogimine',
    'ldap_config_text'  => 'LDAP-i konfiguratsiooniseadeid saab leida Admin> Seaded. (Valikuline) valitud asukoht määratakse kõigi imporditud kasutajate jaoks.',
    'print_assigned'    => 'Prindi kõik varad',
    'email_assigned'    => 'Emaili Nimekiri Väljastatud Varadest',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Kasutaja :name valdusesse antud tarkvara',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Vaata kasutajat :name',
    'usercsv'           => 'CSV fail',
    'two_factor_admin_optin_help' => 'Sinu praegused admin seaded lubavad kahe-astmelist autantimis jõustada valikulselt. ',
    'two_factor_enrolled' => '2FA-seade on registreeritud',
    'two_factor_active'   => '2FA aktiivne ',
    'user_deactivated'  => 'Kasutaja ei saa sisse logida',
    'user_activated'  => 'Kasutaja saab sisse logida',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Uuenda kõik vahendid nendele kasutajatele sellesse olekusse',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'See on kaugkasutaja',
    'remote'   => 'Remote',
    'remote_help' => 'See võib olla kasulik, kui vajad kaugkasutajate filtrit inimestest, kes käivad harva või ei käi üldse ettevõtte füüsilistes asukohtades.',
    'not_remote_label' => 'See ei ole kaugkasutaja',
    'vip_label' => 'VIP kasutaja',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Loo kasutaja',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
